oslosphinx Style Commandments
===========================

- Step 1: Read the OpenStack Style Commandments
  http://docs.openstack.org/developer/hacking/
- Step 2: Read on

oslosphinx Specific Commandments
---------------------------------

None so far

